summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndreas Brachold <vdr07@deltab.de>2009-01-01 16:55:40 +0000
committerAndreas Brachold <vdr07@deltab.de>2009-01-01 16:55:40 +0000
commit66381026cbfd6a7fe38d77774c5451723ac35c92 (patch)
treee2f0af63a89a777c58a5d6c6bfb8f5e76c5e843c
parent6dacbe7d0b46212d8951d00832c8fdb1b15569e5 (diff)
downloadxxv-66381026cbfd6a7fe38d77774c5451723ac35c92.tar.gz
xxv-66381026cbfd6a7fe38d77774c5451723ac35c92.tar.bz2
* Add handler for following(nx)
* Add missing translations
-rw-r--r--skins/jason/locale/lang-de.js9
-rw-r--r--skins/jason/menus.js2
-rw-r--r--skins/jason/now.js25
-rw-r--r--skins/jason/remote.js6
4 files changed, 30 insertions, 12 deletions
diff --git a/skins/jason/locale/lang-de.js b/skins/jason/locale/lang-de.js
index e9dc689..b5de16f 100644
--- a/skins/jason/locale/lang-de.js
+++ b/skins/jason/locale/lang-de.js
@@ -19,6 +19,7 @@ Ext.xxv.MessageBox.prototype.szSuccess = "Erfolgreich!";
Ext.xxv.MainMenu.prototype.szMenuXXV = "XXV";
Ext.xxv.MainMenu.prototype.szMenuProgramming = "Programmierung";
Ext.xxv.MainMenu.prototype.szMenuMedia = "Medien";
+Ext.xxv.MainMenu.prototype.szMenuRemote = "Fernzugriff";
Ext.xxv.MainMenu.prototype.szMenuView = "Anzeige";
Ext.xxv.MainMenu.prototype.szMenuItemSetup = "Einstellungen";
Ext.xxv.MainMenu.prototype.szGlobalSettings = "Globale Einstellungen";
@@ -86,7 +87,9 @@ Ext.xxv.chronicleGrid.prototype.szLoadException = "Konnte keine Daten der Chroni
Ext.xxv.chronicleGrid.prototype.szDeleteSuccess = "Eintrag der Chronik erfolgreich gelöscht.\r\n{0}";
Ext.xxv.chronicleGrid.prototype.szDeleteFailure = "Konnte Eintrag der Chronik nicht löschen!\r\n{0}";
-Ext.xxv.NowGrid.prototype.szTitle = "Jetzt";
+Ext.xxv.NowGrid.prototype.szTitle = "Programmführer";
+Ext.xxv.NowGrid.prototype.szPresent = "Jetzt";
+Ext.xxv.NowGrid.prototype.szFollowing = "Folgend";
Ext.xxv.NowGrid.prototype.szFindReRun = "Suche Wiederholung";
Ext.xxv.NowGrid.prototype.szProgram = "Zeige Programm";
Ext.xxv.NowGrid.prototype.szRecord = "Aufnehmen";
@@ -198,6 +201,10 @@ Ext.xxv.usersGrid.prototype.szLoadException = "Konnte keine Daten über die Anwe
Ext.xxv.usersGrid.prototype.szDeleteSuccess = "Anwenderzugang erfolgreich gelöscht.\r\n{0}";
Ext.xxv.usersGrid.prototype.szDeleteFailure = "Konnte Anwenderzugang nicht löschen!\r\n{0}";
+Ext.xxv.MonitorWindow.prototype.szTitle = "Monitor";
+
+Ext.xxv.RemoteWindow.prototype.szTitle = "Fernbedienung";
+Ext.xxv.RemoteWindow.prototype.szRemoteFailure = "Konnte Daten der Fernbedienung nicht übertragen!\r\n{0}";
Ext.ux.Multiselect.prototype.minLengthText = 'Mindestens sind {0} Einträge notwendig';
Ext.ux.Multiselect.prototype.maxLengthText = 'Maximal sind {0} Einträge erlaubt';
diff --git a/skins/jason/menus.js b/skins/jason/menus.js
index 74024b2..b3daf54 100644
--- a/skins/jason/menus.js
+++ b/skins/jason/menus.js
@@ -233,7 +233,7 @@ Ext.extend(Ext.xxv.MainMenu, Ext.Toolbar, {
szMenuXXV : 'XXV'
,szMenuProgramming : 'Programming'
,szMenuMedia : 'Media'
- ,szMenuRemote : 'Remote'
+ ,szMenuRemote : 'Remote access'
,szMenuView : 'View'
,szMenuItemSetup : 'Setup'
diff --git a/skins/jason/now.js b/skins/jason/now.js
index 9eed570..7e99a0d 100644
--- a/skins/jason/now.js
+++ b/skins/jason/now.js
@@ -50,7 +50,8 @@ Ext.xxv.NowGrid = function(viewer) {
this.store.setDefaultSort('rang', "ASC");
var range = new Array();
- range.push([this.szTitle,0]);
+ range.push([this.szPresent,0]);
+ range.push([this.szFollowing,1]);
for(var i = 0, len = configuration.periods.length; i < len; i++){
range.push([configuration.periods[i],configuration.periods[i]]);
}
@@ -142,7 +143,9 @@ Ext.xxv.NowGrid = function(viewer) {
Ext.extend(Ext.xxv.NowGrid, Ext.grid.GridPanel, {
- szTitle : "Present"
+ szTitle : "Program guide"
+ ,szPresent : "Present"
+ ,szFollowing : "Following"
,szFindReRun : "Find rerun"
,szProgram : "Show program"
,szRecord : "Record"
@@ -166,11 +169,16 @@ Ext.extend(Ext.xxv.NowGrid, Ext.grid.GridPanel, {
}
delete(this.store.baseParams['data']);
var time = this.timefield.getValue();
- if(time) {
+ if(time && time != '1') {
this.store.baseParams.data = time;
+ this.store.baseParams.cmd = 'n';
} else {
this.timefield.emptyText = new Date().dateFormat('H:i');
- this.timefield.setValue(0);
+ this.timefield.setValue(time);
+ if(time != '1')
+ this.store.baseParams.cmd = 'n';
+ else
+ this.store.baseParams.cmd = 'nx';
}
this.preview.clear();
}
@@ -181,17 +189,20 @@ Ext.extend(Ext.xxv.NowGrid, Ext.grid.GridPanel, {
}
this.getSelectionModel().selectFirstRow();
var time = this.timefield.getValue();
- if(time) {
+ if(time && time != '1') {
if(store.reader.meta
&& store.reader.meta.param
&& store.reader.meta.param.zeit) {
var datum = new Date(store.reader.meta.param.zeit * 1000);
this.ownerCt.SetPanelTitle(datum.dateFormat('l - H:i'));
} else {
- this.ownerCt.SetPanelTitle(time);
+ this.ownerCt.SetPanelTitle(this.szTitle + " - " + time);
}
} else {
- this.ownerCt.SetPanelTitle(this.szTitle + " - " + this.timefield.emptyText);
+ if(time != '1')
+ this.ownerCt.SetPanelTitle(this.szPresent + " - " + this.timefield.emptyText);
+ else
+ this.ownerCt.SetPanelTitle(this.szFollowing + " - " + this.timefield.emptyText);
}
}
,onSelectProgram : function(grid, index, e) {
diff --git a/skins/jason/remote.js b/skins/jason/remote.js
index 9616315..c69ccc5 100644
--- a/skins/jason/remote.js
+++ b/skins/jason/remote.js
@@ -110,9 +110,9 @@ Ext.xxv.RemoteWindow = function() {
Ext.extend(Ext.xxv.RemoteWindow, Ext.Window, {
- szTitle : "Remote"
- //,szRemoteSuccess : "Successful transmit remote control.\r\n{0}"
- ,szRemoteFailure : "Couldn't transmit remote control!\r\n{0}"
+ szTitle : "Remote control"
+ //,szRemoteSuccess : "Successful transmit remote control data.\r\n{0}"
+ ,szRemoteFailure : "Couldn't transmit remote control data!\r\n{0}"
,hide : function(){
if(this.task) {
Ext.TaskMgr.stop(this.task);